==> dshell-1.0.16.tar.gz: lib/script/commands/run.dart <==
import 'package:dshell/pubspec/pubspec_manager.dart';

import '../../settings.dart';
import '../dart_sdk.dart';
import '../flags.dart';
import '../project.dart';
import '../project_cache.dart';
import '../runner.dart';
import '../script.dart';
import 'commands.dart';

/// Runs a dart script.
class RunCommand extends Command {
  static const String NAME = "run";

  RunCommand() : super(NAME);

  ///
  /// [arguments] - the arguments passed directly to the run command.
  /// Returns the [exitcode];
  @override
  int run(List<Flag> selectedFlags, List<String> arguments) {
    Script.validate(arguments);

    Script script = Script.fromArg(arguments[0]);

    VirtualProject project = ProjectCache().loadProject(script);

    if (PubSpecManager(project).isCleanRequired()) {
      project.clean();
    }

    List<String> scriptArguments = List();

    if (arguments.length > 1) {
      scriptArguments = arguments.sublist(1);
    }

    final DartSdk sdk = DartSdk();
    final ScriptRunner runner = ScriptRunner(sdk, project, scriptArguments);

    final int exitCode = runner.exec();

    return exitCode;
  }

  String usage() => "run <script path.dart>";

  String description() =>
      '''Runs the given script. This command is provided for the sake of symmetry. 
 The recommended method is to use the simplier form ${Settings().appname} <script path.dart>''';

  // CommandRun.fromScriptArg(String argument) {
  //   Script.validate(argument);
  //   Script script = Script.fromArg(selectedFlags.values.toList(), argument);
  //   script.run(selectedFlags, subarguments);
  // }
}

==> dshell-1.0.17.tar.gz: lib/script/commands/run.dart <==
import 'package:dshell/pubspec/pubspec_manager.dart';

import '../../settings.dart';
import '../dart_sdk.dart';
import '../flags.dart';
import '../project_cache.dart';
import '../runner.dart';
import '../script.dart';
import 'commands.dart';

/// Runs a dart script.
class RunCommand extends Command {
  static const String NAME = 'run';

  RunCommand() : super(NAME);

  ///
  /// [arguments] - the arguments passed directly to the run command.
  /// Returns the [exitcode];
  @override
  int run(List<Flag> selectedFlags, List<String> arguments) {
    Script.validate(arguments);

    var script = Script.fromFile(arguments[0]);

    var project = ProjectCache().loadProject(script);

    if (PubSpecManager(project).isCleanRequired()) {
      project.clean();
    }

    var scriptArguments = <String>[];

    if (arguments.length > 1) {
      scriptArguments = arguments.sublist(1);
    }

    final  sdk = DartSdk();
    final  runner = ScriptRunner(sdk, project, scriptArguments);

    final  exitCode = runner.exec();

    return exitCode;
  }

  @override
  String usage() => 'run <script path.dart>';

  @override
  String description() =>
      '''Runs the given script. This command is provided for the sake of symmetry. 
 The recommended method is to use the simplier form ${Settings().appname} <script path.dart>''';

  // CommandRun.fromScriptArg(String argument) {
  //   Script.validate(argument);
  //   Script script = Script.fromArg(selectedFlags.values.toList(), argument);
  //   script.run(selectedFlags, subarguments);
  // }
}
